@@ -1,7 +1,7 @@
 /*
  * ftp_control.c
  *
- * Copyright (C) 2016 - ntop.org
+ * Copyright (C) 2016-19 - ntop.org
  *
  * This file is part of nDPI, an open source deep packet inspection
  * library based on the OpenDPI and PACE technology by ipoque GmbH
@@ -21,10 +21,12 @@
  * 
  */
 
+#include "ndpi_protocol_ids.h"
+
+#define NDPI_CURRENT_PROTO NDPI_PROTOCOL_FTP_CONTROL
 
 #include "ndpi_api.h"
 
-#ifdef NDPI_PROTOCOL_FTP_CONTROL
 
 static void ndpi_int_ftp_control_add_connection(struct ndpi_detection_module_struct *ndpi_struct, struct ndpi_flow_struct *flow) {
   ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_FTP_CONTROL, NDPI_PROTOCOL_UNKNOWN);
@@ -944,31 +946,29 @@ static void ndpi_check_ftp_control(struct ndpi_detection_module_struct *ndpi_str
   
     /* Exclude SMTP, which uses similar commands. */
     if (packet->tcp->dest == htons(25) || packet->tcp->source == htons(25)) {
-      NDPI_LOG(NDPI_PROTOCOL_FTP_CONTROL, ndpi_struct, NDPI_LOG_DEBUG, "Exclude FTP_CONTROL.\n");
-      NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_FTP_CONTROL);
+      NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
       return;
     }
   
     /* Break after 20 packets. */
     if (flow->packet_counter > 20) {
-      NDPI_LOG(NDPI_PROTOCOL_FTP_CONTROL, ndpi_struct, NDPI_LOG_DEBUG, "Exclude FTP_CONTROL.\n");
-      NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_FTP_CONTROL);
+      NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
       return;
     }
   
     /* Check if we so far detected the protocol in the request or not. */
     if (flow->ftp_control_stage == 0) {
-      NDPI_LOG(NDPI_PROTOCOL_FTP_CONTROL, ndpi_struct, NDPI_LOG_DEBUG, "FTP_CONTROL stage 0: \n");
+      NDPI_LOG_DBG2(ndpi_struct, "FTP_CONTROL stage 0: \n");
      
       if ((payload_len > 0) && ndpi_ftp_control_check_request(packet->payload, payload_len)) {
-	NDPI_LOG(NDPI_PROTOCOL_FTP_CONTROL, ndpi_struct, NDPI_LOG_DEBUG, "Possible FTP_CONTROL request detected, we will look further for the response...\n");
+	NDPI_LOG_DBG2(ndpi_struct, "Possible FTP_CONTROL request detected, we will look further for the response..\n");
        
 	/* Encode the direction of the packet in the stage, so we will know when we need to look for the response packet. */
 	flow->ftp_control_stage = packet->packet_direction + 1;
       }
      
     } else {
-      NDPI_LOG(NDPI_PROTOCOL_FTP_CONTROL, ndpi_struct, NDPI_LOG_DEBUG, "FTP_CONTROL stage %u: \n", flow->ftp_control_stage);
+      NDPI_LOG_DBG2(ndpi_struct, "FTP_CONTROL stage %u: \n", flow->ftp_control_stage);
     
       /* At first check, if this is for sure a response packet (in another direction. If not, do nothing now and return. */
       if ((flow->ftp_control_stage - packet->packet_direction) == 1) {
@@ -977,10 +977,10 @@ static void ndpi_check_ftp_control(struct ndpi_detection_module_struct *ndpi_str
     
       /* This is a packet in another direction. Check if we find the proper response. */
       if ((payload_len > 0) && ndpi_ftp_control_check_response(packet->payload, payload_len)) {
-	NDPI_LOG(NDPI_PROTOCOL_FTP_CONTROL, ndpi_struct, NDPI_LOG_DEBUG, "Found FTP_CONTROL.\n");
+	NDPI_LOG_INFO(ndpi_struct, "found FTP_CONTROL\n");
 	ndpi_int_ftp_control_add_connection(ndpi_struct, flow);
       } else {
-	NDPI_LOG(NDPI_PROTOCOL_FTP_CONTROL, ndpi_struct, NDPI_LOG_DEBUG, "The reply did not seem to belong to FTP_CONTROL, resetting the stage to 0...\n");
+	NDPI_LOG_DBG2(ndpi_struct, "The reply did not seem to belong to FTP_CONTROL, resetting the stage to 0\n");
 	flow->ftp_control_stage = 0;
       }
     }
@@ -990,7 +990,7 @@ static void ndpi_check_ftp_control(struct ndpi_detection_module_struct *ndpi_str
 void ndpi_search_ftp_control(struct ndpi_detection_module_struct *ndpi_struct, struct ndpi_flow_struct *flow) {
   struct ndpi_packet_struct *packet = &flow->packet;
 
-  NDPI_LOG(NDPI_PROTOCOL_FTP_CONTROL, ndpi_struct, NDPI_LOG_DEBUG, "FTP_CONTROL detection...\n");
+  NDPI_LOG_DBG(ndpi_struct, "search FTP_CONTROL\n");
 
   /* skip marked packets */
   if (packet->detected_protocol_stack[0] != NDPI_PROTOCOL_FTP_CONTROL) {
@@ -1012,5 +1012,3 @@ void init_ftp_control_dissector(struct ndpi_detection_module_struct *ndpi_struct
 
   *id += 1;
 }
-
-#endif
