@@ -1,7 +1,7 @@
 /*
  * kakaotalk_voice.c
  *
- * Copyright (C) 2015 - ntop.org
+ * Copyright (C) 2015-19 - ntop.org
  *
  * This module is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -24,13 +24,18 @@
 
   http://www.kakao.com/services/talk/voices
 */
+#include "ndpi_protocol_ids.h"
+
+#define NDPI_CURRENT_PROTO NDPI_PROTOCOL_KAKAOTALK_VOICE
+
 #include "ndpi_api.h"
 
 
-#ifdef NDPI_PROTOCOL_KAKAOTALK_VOICE
 void ndpi_search_kakaotalk_voice(struct ndpi_detection_module_struct *ndpi_struct, struct ndpi_flow_struct *flow) {
   struct ndpi_packet_struct *packet = &flow->packet;
   
+  NDPI_LOG_DBG(ndpi_struct, "search kakaotalk_voice\n");
+
   if(packet->iph
      && packet->udp
      && (packet->payload_packet_len >= 4)
@@ -48,18 +53,19 @@ void ndpi_search_kakaotalk_voice(struct ndpi_detection_module_struct *ndpi_struc
 
       if(((ntohl(packet->iph->saddr) & 0xFFFF0000 /* 255.255.0.0 */) == 0x01C90000 /* 1.201.0.0/16 */)
 	 || ((ntohl(packet->iph->daddr) & 0xFFFF0000 /* 255.255.0.0 */) == 0x01C90000 /* 1.201.0.0/16 */)) {
+	NDPI_LOG_INFO(ndpi_struct, "found kakaotalk_voice\n");
 	ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_KAKAOTALK_VOICE, NDPI_PROTOCOL_UNKNOWN);
 	return;
       }
     } 
   }
   
-  NDPI_LOG(NDPI_PROTOCOL_KAKAOTALK_VOICE, ndpi_struct, NDPI_LOG_DEBUG, "Exclude kakaotalk_voice.\n");
-  NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_KAKAOTALK_VOICE);
+  NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
 }
 
 
-void init_kakaotalk_voice_dissector(struct ndpi_detection_module_struct *ndpi_struct, u_int32_t *id, NDPI_PROTOCOL_BITMASK *detection_bitmask)
+void init_kakaotalk_voice_dissector(struct ndpi_detection_module_struct *ndpi_struct,
+				    u_int32_t *id, NDPI_PROTOCOL_BITMASK *detection_bitmask)
 {
   ndpi_set_bitmask_protocol_detection("KakaoTalk_Voice", ndpi_struct, detection_bitmask, *id,
 				      NDPI_PROTOCOL_KAKAOTALK_VOICE,
@@ -70,4 +76,3 @@ void init_kakaotalk_voice_dissector(struct ndpi_detection_module_struct *ndpi_st
   *id += 1;
 }
 
-#endif
