@@ -1,11 +1,7 @@
 /*
  * quic.c
  *
- * Copyright (C) 2012-16 - ntop.org
- *
- * Based on code of:
- * Andrea Buscarinu - <andrea.buscarinu@gmail.com>
- * Michele Campus - <campus@ntop.org>
+ * Copyright (C) 2012-19 - ntop.org
  *
  * This module is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -20,11 +16,21 @@
  * You should have received a copy of the GNU Lesser General Public License.
  * If not, see <http://www.gnu.org/licenses/>.
  *
+ * Based on code of:
+ * Andrea Buscarinu - <andrea.buscarinu@gmail.com>
+ * Michele Campus - <campus@ntop.org>
+ *
  */
 
-#include "ndpi_api.h"
+#if defined __FreeBSD__ || defined __NetBSD__ || defined __OpenBSD__
+#include <sys/endian.h>
+#endif
 
-#ifdef NDPI_PROTOCOL_QUIC
+#include "ndpi_protocol_ids.h"
+
+#define NDPI_CURRENT_PROTO NDPI_PROTOCOL_QUIC
+
+#include "ndpi_api.h"
 
 static int quic_ports(u_int16_t sport, u_int16_t dport)
 {
@@ -68,22 +74,44 @@ void ndpi_search_quic(struct ndpi_detection_module_struct *ndpi_struct,
   u_int seq_len = quic_len((packet->payload[0] & 0x30) >> 4);
   u_int quic_hlen = 1 /* flags */ + version_len + seq_len + cid_len;
 
+  NDPI_LOG_DBG(ndpi_struct, "search QUIC\n");
+
   if(packet->udp != NULL
      && (udp_len > (quic_hlen+4 /* QXXX */))
-     && ((packet->payload[0] & 0xC2) == 0x00)
+     // && ((packet->payload[0] & 0xC2) == 0x00)
      && (quic_ports(ntohs(packet->udp->source), ntohs(packet->udp->dest)))
      ) {
     int i;
 
-    if((version_len > 0) && (packet->payload[1+cid_len] != 'Q'))
-      goto no_quic;
+    if((packet->payload[1] == 'Q')
+       && (packet->payload[2] == '0')
+       && (packet->payload[3] == '4')
+       && (packet->payload[4] == '6')
+       && (version_len == 1)
+       )
+      quic_hlen = 18; /* TODO: Better handle Q046 */
+    else {
+      u_int16_t potential_stun_len = ntohs((*((u_int16_t*)&packet->payload[2])));
+      
+      if((version_len > 0) && (packet->payload[1+cid_len] != 'Q'))
+	goto no_quic;
 
-    NDPI_LOG(NDPI_PROTOCOL_QUIC, ndpi_struct, NDPI_LOG_DEBUG, "found QUIC.\n");
-    ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_QUIC, NDPI_PROTOCOL_UNKNOWN);
+      if((version_len == 0) && ((packet->payload[0] & 0xC3 /* ignore CID len/packet number */) != 0))
+	goto no_quic;      
 
-    if(packet->payload[quic_hlen+12] != 0xA0)
-      quic_hlen++;
-	     
+
+      /* Heuristic to see if this packet could be a STUN packet */
+      if((potential_stun_len /* STUN message len */ < udp_len)
+	 && ((potential_stun_len+25 /* Attribute header overhead we assume is max */) /* STUN message len */ > udp_len))	
+	return; /* This could be STUN, let's skip this packet */      
+      
+      NDPI_LOG_INFO(ndpi_struct, "found QUIC\n");
+      ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_QUIC, NDPI_PROTOCOL_UNKNOWN);
+      
+      if(packet->payload[quic_hlen+12] != 0xA0)
+	quic_hlen++;
+    }
+    
     if(udp_len > quic_hlen + 16 + 4) {
       if(!strncmp((char*)&packet->payload[quic_hlen+16], "CHLO" /* Client Hello */, 4)) {
 	/* Check if SNI (Server Name Identification) is present */
@@ -92,8 +120,8 @@ void ndpi_search_quic(struct ndpi_detection_module_struct *ndpi_struct,
 	     && (packet->payload[i+1] == 'N')
 	     && (packet->payload[i+2] == 'I')
 	     && (packet->payload[i+3] == 0)) {
-	    u_int32_t offset = *((u_int32_t*)&packet->payload[i+4]);
-	    u_int32_t prev_offset = *((u_int32_t*)&packet->payload[i-4]);
+	    u_int32_t offset = (*((u_int32_t*)&packet->payload[i+4]));
+	    u_int32_t prev_offset = (*((u_int32_t*)&packet->payload[i-4]));
 	    int len = offset-prev_offset;
 	    int sni_offset = i+prev_offset+1;
 
@@ -101,20 +129,23 @@ void ndpi_search_quic(struct ndpi_detection_module_struct *ndpi_struct,
 	      sni_offset++;
 
 	    if((sni_offset+len) < udp_len) {
-	      int max_len = sizeof(flow->host_server_name)-1, j = 0;
-
-	      if(len > max_len) len = max_len;
-
-	      while((len > 0) && (sni_offset < udp_len)) {
-		flow->host_server_name[j++] = packet->payload[sni_offset];
-		sni_offset++, len--;
+	      if(!ndpi_struct->disable_metadata_export) {
+		int max_len = sizeof(flow->host_server_name)-1, j = 0;
+		ndpi_protocol_match_result ret_match;
+		
+		if(len > max_len) len = max_len;
+		
+		while((len > 0) && (sni_offset < udp_len)) {
+		  flow->host_server_name[j++] = packet->payload[sni_offset];
+		  sni_offset++, len--;
+		}
+		
+		ndpi_match_host_subprotocol(ndpi_struct, flow, 
+					    (char *)flow->host_server_name,
+					    strlen((const char*)flow->host_server_name),
+					    &ret_match,
+					    NDPI_PROTOCOL_QUIC);
 	      }
-
-	      ndpi_match_host_subprotocol(ndpi_struct, flow, 
-					  (char *)flow->host_server_name,
-					  strlen((const char*)flow->host_server_name),
-					  NDPI_PROTOCOL_QUIC);
-	    
 	    }
 
 	    break;
@@ -126,8 +157,7 @@ void ndpi_search_quic(struct ndpi_detection_module_struct *ndpi_struct,
   }
 
  no_quic:
-  NDPI_LOG(NDPI_PROTOCOL_QUIC, ndpi_struct, NDPI_LOG_DEBUG, "exclude QUIC.\n");
-  NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_QUIC);
+  NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
 }
 
 /* ***************************************************************** */
@@ -142,5 +172,3 @@ void init_quic_dissector(struct ndpi_detection_module_struct *ndpi_struct, u_int
 
   *id += 1;
 }
-
-#endif /* NDPI_PROTOCOL_QUIC */
