@@ -1,7 +1,7 @@
 /*
  * socks4.c
  *
- * Copyright (C) 2016 - ntop.org
+ * Copyright (C) 2016-19 - ntop.org
  * Copyright (C) 2014 Tomasz Bujlow <tomasz@skatnet.dk>
  *
  * The signature is based on the Libprotoident library.
@@ -23,11 +23,12 @@
  * along with nDPI.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
+#include "ndpi_protocol_ids.h"
 
+#define NDPI_CURRENT_PROTO NDPI_PROTOCOL_SOCKS
 
 #include "ndpi_api.h"
 
-#ifdef NDPI_PROTOCOL_SOCKS
 static void ndpi_int_socks_add_connection(struct ndpi_detection_module_struct *ndpi_struct, struct ndpi_flow_struct *flow)
 {
   ndpi_set_detected_protocol(ndpi_struct, flow, NDPI_PROTOCOL_SOCKS, NDPI_PROTOCOL_UNKNOWN);
@@ -40,25 +41,24 @@ static void ndpi_check_socks4(struct ndpi_detection_module_struct *ndpi_struct,
 
   /* Break after 20 packets. */
   if(flow->packet_counter > 20) {
-    NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "Exclude SOCKS4.\n");
-    NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOCKS);
+    NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
     return;
   }
 
   /* Check if we so far detected the protocol in the request or not. */
   if(flow->socks4_stage == 0) {
-    NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "SOCKS4 stage 0: \n");
+    NDPI_LOG_DBG2(ndpi_struct, "SOCKS4 stage 0: \n");
     
     if(payload_len >= 9 && packet->payload[0] == 0x04 && 
       (packet->payload[1] == 0x01 || packet->payload[1] == 0x02) &&
       packet->payload[payload_len - 1] == 0x00)  {
-      NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "Possible SOCKS4 request detected, we will look further for the response...\n");
+      NDPI_LOG_DBG2(ndpi_struct, "Possible SOCKS4 request detected, we will look further for the response\n");
       /* TODO: check port and ip address is valid */
       /* Encode the direction of the packet in the stage, so we will know when we need to look for the response packet. */
       flow->socks4_stage = packet->packet_direction + 1;
     }
   } else {
-    NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "SOCKS4 stage %u: \n", flow->socks4_stage);
+    NDPI_LOG_DBG2(ndpi_struct, "SOCKS4 stage %u: \n", flow->socks4_stage);
 
     /* At first check, if this is for sure a response packet (in another direction. If not, do nothing now and return. */
     if((flow->socks4_stage - packet->packet_direction) == 1) {
@@ -66,10 +66,10 @@ static void ndpi_check_socks4(struct ndpi_detection_module_struct *ndpi_struct,
     }
     /* This is a packet in another direction. Check if we find the proper response. */
     if(payload_len == 8 && packet->payload[0] == 0x00 && packet->payload[1] >= 0x5a && packet->payload[1] <= 0x5d) {
-      NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "Found SOCKS4.\n");
+      NDPI_LOG_INFO(ndpi_struct, "found SOCKS4\n");
       ndpi_int_socks_add_connection(ndpi_struct, flow);
     } else {
-      NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "The reply did not seem to belong to SOCKS4, resetting the stage to 0...\n");
+      NDPI_LOG_DBG2(ndpi_struct, "The reply did not seem to belong to SOCKS4, resetting the stage to 0\n");
       flow->socks4_stage = 0;
     }
   }
@@ -82,24 +82,23 @@ static void ndpi_check_socks5(struct ndpi_detection_module_struct *ndpi_struct,
 
   /* Break after 20 packets. */
   if(flow->packet_counter > 20) {
-    NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "Exclude SOCKS5.\n");
-    NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOCKS);
+    NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
     return;
   }
 
   /* Check if we so far detected the protocol in the request or not. */
   if(flow->socks5_stage == 0) {
-    NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "SOCKS5 stage 0: \n");
+    NDPI_LOG_DBG2(ndpi_struct, "SOCKS5 stage 0: \n");
 
     if((payload_len == 3) && (packet->payload[0] == 0x05) && (packet->payload[1] == 0x01) && (packet->payload[2] == 0x00)) {
-      NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "Possible SOCKS5 request detected, we will look further for the response...\n");
+      NDPI_LOG_DBG2(ndpi_struct, "Possible SOCKS5 request detected, we will look further for the response\n");
 
       /* Encode the direction of the packet in the stage, so we will know when we need to look for the response packet. */
       flow->socks5_stage = packet->packet_direction + 1;
     }
 
   } else {
-    NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "SOCKS5 stage %u: \n", flow->socks5_stage);
+    NDPI_LOG_DBG2(ndpi_struct, "SOCKS5 stage %u: \n", flow->socks5_stage);
 
     /* At first check, if this is for sure a response packet (in another direction. If not, do nothing now and return. */
     if((flow->socks5_stage - packet->packet_direction) == 1) {
@@ -108,10 +107,10 @@ static void ndpi_check_socks5(struct ndpi_detection_module_struct *ndpi_struct,
 
     /* This is a packet in another direction. Check if we find the proper response. */
     if((payload_len == 0) || ((payload_len == 2) && (packet->payload[0] == 0x05) && (packet->payload[1] == 0x00))) {
-      NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "Found SOCKS5.\n");
+      NDPI_LOG_INFO(ndpi_struct, "found SOCKS5\n");
       ndpi_int_socks_add_connection(ndpi_struct, flow);
     } else {
-      NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "The reply did not seem to belong to SOCKS5, resetting the stage to 0...\n");
+      NDPI_LOG_DBG2(ndpi_struct, "The reply did not seem to belong to SOCKS5, resetting the stage to 0\n");
       flow->socks5_stage = 0;
     }
 
@@ -122,7 +121,7 @@ void ndpi_search_socks(struct ndpi_detection_module_struct *ndpi_struct, struct
 {
   struct ndpi_packet_struct *packet = &flow->packet;
 
-  NDPI_LOG(NDPI_PROTOCOL_SOCKS, ndpi_struct, NDPI_LOG_DEBUG, "SOCKS detection...\n");
+  NDPI_LOG_DBG(ndpi_struct, "search SOCKS\n");
 
   /* skip marked packets */
   if(packet->detected_protocol_stack[0] != NDPI_PROTOCOL_SOCKS) {
@@ -147,4 +146,3 @@ void init_socks_dissector(struct ndpi_detection_module_struct *ndpi_struct, u_in
   *id += 1;
 }
 
-#endif
