@@ -1,7 +1,7 @@
 /*
  * xbox.c
  *
- * Copyright (C) 2016 - ntop.org
+ * Copyright (C) 2016-19 - ntop.org
  *
  * This file is part of nDPI, an open source deep packet inspection
  * library based on the OpenDPI and PACE technology by ipoque GmbH
@@ -21,9 +21,10 @@
  * 
  */
 
-#include "ndpi_protocols.h"
+#include "ndpi_protocol_ids.h"
 
-#ifdef NDPI_PROTOCOL_XBOX
+#define NDPI_CURRENT_PROTO NDPI_PROTOCOL_XBOX
+#include "ndpi_api.h"
 
 static void ndpi_int_xbox_add_connection(struct ndpi_detection_module_struct
 					 *ndpi_struct, struct ndpi_flow_struct *flow)
@@ -36,9 +37,6 @@ void ndpi_search_xbox(struct ndpi_detection_module_struct *ndpi_struct, struct n
 {
   struct ndpi_packet_struct *packet = &flow->packet;
 	
-  //  struct ndpi_id_struct *src = flow->src;
-  //  struct ndpi_id_struct *dst = flow->dst;
-
   /*
    * XBOX UDP DETCTION ONLY
    * the xbox TCP detection is done by http code
@@ -49,7 +47,7 @@ void ndpi_search_xbox(struct ndpi_detection_module_struct *ndpi_struct, struct n
     u_int16_t dport = ntohs(packet->udp->dest);
     u_int16_t sport = ntohs(packet->udp->source);
 
-    NDPI_LOG(NDPI_PROTOCOL_XBOX, ndpi_struct, NDPI_LOG_DEBUG, "search xbox\n");
+    NDPI_LOG_DBG(ndpi_struct, "search xbox\n");
 
     if (packet->payload_packet_len > 12 &&
 	get_u_int32_t(packet->payload, 0) == 0 && packet->payload[5] == 0x58 &&
@@ -62,7 +60,7 @@ void ndpi_search_xbox(struct ndpi_detection_module_struct *ndpi_struct, struct n
 	  (packet->payload[4] == 0x06 && packet->payload[6] == 0x4e)) {
 
 	ndpi_int_xbox_add_connection(ndpi_struct, flow);
-	NDPI_LOG(NDPI_PROTOCOL_XBOX, ndpi_struct, NDPI_LOG_DEBUG, "xbox udp connection detected\n");
+	NDPI_LOG_INFO(ndpi_struct, "found xbox udp connection detected\n");
 	return;
       }
     }
@@ -76,20 +74,22 @@ void ndpi_search_xbox(struct ndpi_detection_module_struct *ndpi_struct, struct n
 	    || (packet->payload_packet_len == 28 && ntohl(get_u_int32_t(packet->payload, 0)) == 0x015f2c00))) {
       if (flow->l4.udp.xbox_stage == 1) {
 	ndpi_int_xbox_add_connection(ndpi_struct, flow);
-	NDPI_LOG(NDPI_PROTOCOL_XBOX, ndpi_struct, NDPI_LOG_DEBUG, "xbox udp connection detected\n");
+	NDPI_LOG_INFO(ndpi_struct, "found xbox udp connection detected\n");
 	return;
       }
-      NDPI_LOG(NDPI_PROTOCOL_XBOX, ndpi_struct, NDPI_LOG_DEBUG, "maybe xbox.\n");
+      NDPI_LOG_DBG(ndpi_struct, "maybe xbox\n");
       flow->l4.udp.xbox_stage++;
       return;
+    } else if ((dport == 3075 || dport == 3076 || dport == 3077 || dport == 3078) ||
+          (sport == 3075 || sport == 3076 || sport == 3077 || sport == 3078)) {
+	ndpi_int_xbox_add_connection(ndpi_struct, flow);
+	NDPI_LOG_INFO(ndpi_struct, "found xbox udp port connection detected\n");
+	return;
     }
 
     /* exclude here all non matched udp traffic, exclude here tcp only if http has been excluded, because xbox could use http */
-#ifdef NDPI_PROTOCOL_HTTP
     if(NDPI_COMPARE_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_HTTP) != 0) {
-#endif
-      NDPI_LOG(NDPI_PROTOCOL_XBOX, ndpi_struct, NDPI_LOG_DEBUG, "xbox udp excluded.\n");
-      NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_XBOX);
+      NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
     }
   }
   /* to not exclude tcp traffic here, done by http code... */
@@ -101,11 +101,10 @@ void init_xbox_dissector(struct ndpi_detection_module_struct *ndpi_struct, u_int
   ndpi_set_bitmask_protocol_detection("Xbox", ndpi_struct, detection_bitmask, *id,
 				      NDPI_PROTOCOL_XBOX,
 				      ndpi_search_xbox,
-				      NDPI_SELECTION_BITMASK_PROTOCOL_V4_V6_TCP_WITH_PAYLOAD,
+				      NDPI_SELECTION_BITMASK_PROTOCOL_V4_V6_UDP_WITH_PAYLOAD,
 				      NO_SAVE_DETECTION_BITMASK_AS_UNKNOWN,
 				      ADD_TO_DETECTION_BITMASK);
 
   *id += 1;
 }
 
-#endif
